@@ -1,11 +1,14 @@
+"""
+
+"""
 import time
 
 import psutil
 
 from lumo.kit.experiment import Experiment
+from lumo.proc.const import EXP_CONST
 from lumo.kit.params import BaseParams
-from lumo.utils.dates import strftime
-from lumo.utils.keys import EXP
+from lumo.proc.date import strftime
 
 
 def wait_pid_stop():
@@ -18,14 +21,15 @@ def wait_pid_stop():
     exp = Experiment(params.exp_name, params.test_name)
     c = 0
     while psutil.pid_exists(params.pid):
-        info = exp.load_info(EXP.STATE)
+        info = exp.load_info(EXP_CONST.INFO_KEY.STATE)
         if 'end_code' in info:
             break
 
-        exp.dump_info(EXP.STATE, {
+        exp.dump_info(EXP_CONST.INFO_KEY.STATE, {
             'end': strftime(),
         }, append=True)
         time.sleep(1)
 
+
 if __name__ == '__main__':
     wait_pid_stop()
