@@ -8,6 +8,10 @@ import torch
 from lumo.contrib.itertools import safe_cycle, poll
 
 
+def identity(x):
+    return x
+
+
 class DataBundler:
     """
     """
@@ -53,6 +57,10 @@ class DataBundler:
         for batch_data in iter:
             yield batch_data
 
+    def __repr__(self):
+        from pprint import pformat
+        return pformat(self.len_dict())
+
     def _append(self, loader, func, name):
         from torch.utils.data import DataLoader
         assert isinstance(loader, (DataLoader, DataBundler))
@@ -116,7 +124,7 @@ class DataBundler:
         return self
 
     def add(self, loader, name=None):
-        self._append(loader, lambda x: x, name)
+        self._append(loader, identity, name)
         return self
 
     @overload
@@ -182,7 +190,3 @@ class DataBundler:
         for loader in args:
             bundler.add(loader)
         return bundler
-
-    def __repr__(self):
-        from pprint import pformat
-        return pformat(self.len_dict())
